@@ -146,14 +146,7 @@ int sbstoken(FILE *sbsfile, char *token)
 	   c == '<' || c == '^' || c == '~' || c == '!' || c == '&' || c == '|')
     {
       t = 0;
-      if (t < TOKENLEN)
-	token[t++] = c;
-      else
-	{
-	  token[t] = '\0';
-	  fprintf(stderr, "sbstrans: before %d: token too long: %s\n", sbslineno, token);
-	  exit(1);
-	}
+      token[t++] = c;
       cprev = c;
       c = sbsgetc(sbsfile);
       if (c == '=' || (cprev == c))
@@ -173,18 +166,19 @@ int sbstoken(FILE *sbsfile, char *token)
     {
       quote = c;
       t = 0;
-      if (t < TOKENLEN)
-	token[t++] = c;
-      else
-	{
-	  token[t] = '\0';
-	  fprintf(stderr, "sbstrans: before %d: token too long: %s\n", sbslineno, token);
-	  exit(1);
-	}
+      token[t++] = c;
+      cprev = c;
       c = sbsgetc(sbsfile);
-      for ( ; c != EOF && c != '\n' && c != quote; c = sbsgetc(sbsfile))
+      for ( ; c != EOF && c != quote; cprev = c, c = sbsgetc(sbsfile))
 	{
-	  if (t < TOKENLEN)
+	  if (c == '\n')
+	    {
+	      if (cprev == '\\')
+		--t;
+	      else
+		break;
+	    }
+	  else if (t < TOKENLEN)
 	    token[t++] = c;
 	  else
 	    {
@@ -206,14 +200,7 @@ int sbstoken(FILE *sbsfile, char *token)
   else
     {
       t = 0;
-      if (t < TOKENLEN)
-	token[t++] = c;
-      else
-	{
-	  token[t] = '\0';
-	  fprintf(stderr, "sbstrans: before %d: token too long: %s\n", sbslineno, token);
-	  exit(1);
-	}
+      token[t++] = c;
       c = sbsgetc(sbsfile);
     }
   token[t] = '\0';
@@ -884,7 +871,8 @@ void datatrans(char *step, FILE *dapfile)
 	{
 	  while (!isdouble && step[s] && step[s] != ';')
 	    {
-	      if ('a' <= step[s] && step[s] <= 'z' && !iskeyword(step + s))
+	      if ((('a' <= step[s] && step[s] <= 'z') || step[s] == '_')
+		  && !iskeyword(step + s))
 		{
 		  s += linecpy(varname, step + s) + 1;
 		  if (step[s] != '(' && strncmp(varname, "first.", 6) &&
@@ -959,7 +947,8 @@ void datatrans(char *step, FILE *dapfile)
 	    {
 	      while (step[s] && step[s] != ';')
 		{
-		  if ('a' <= step[s] && step[s] <= 'z' && !iskeyword(step + s))
+		  if ((('a' <= step[s] && step[s] <= 'z') || step[s] == '_')
+		      && !iskeyword(step + s))
 		    {
 		      s += linecpy(varname, step + s) + 1;
 		      if (step[s] != '(' && strncmp(varname, "first.", 6) &&
